@@ -251,6 +251,53 @@ static COLORS: phf::Map<&'static str, &str> = phf_map! {
     "crimson glory" => "#be0032",
     "cyan" => "#00ffff",
 
+    "daffodil" => "#ffff31",
+    "dandelion" => "#f0e130",
+    "dark blue" => "#00008b",
+    "dark brown" => "#654321",
+    "dark byzantium" => "#5d3954",
+    "dark candy apple red" => "#a40000",
+    "dark cerulean" => "#08457e",
+    "dark chestnut" => "#986960",
+    "dark coral" => "#cd5b45",
+    "dark cyan" => "#008b8b",
+    "dark electric blue" => "#536878",
+    "dark goldenrod" => "#b8860b",
+    "dark gray" => "#a9a9a9",
+    "dark green" => "#013220",
+    "dark jungle green" => "#1a2421",
+    "dark khaki" => "#bdb76b",
+    "dark lava" => "#483c32",
+    "dark lavender" => "#734f96",
+    "dark magenta" => "#8b008b",
+    "dark midnight blue" => "#003366",
+    "dark olive green" => "#556b2f",
+    "dark orange" => "#ff8c00",
+    "dark orchid" => "#9932cc",
+    "dark pastel blue" => "#779ecb",
+    "dark pastel green" => "#03c03c",
+    "dark pastel purple" => "#966fd6",
+    "dark pastel red" => "#c23b22",
+    "dark pink" => "#e75480",
+    "dark powder blue" => "#003399",
+    "dark raspberry" => "#872657",
+    "dark red" => "#8b0000",
+    "dark salmon" => "#e9967a",
+    "dark scarlet" => "#560319",
+    "dark sea green" => "#8fbc8f",
+    "dark sienna" => "#3c1414",
+    "dark slate blue" => "#483d8b",
+    "dark slate gray" => "#2f4f4f",
+    "dark spring green" => "#177245",
+    "dark tan" => "#918151",
+    "dark tangerine" => "#ffa812",
+    "dark taupe" => "#483c32",
+    "dark terra cotta" => "#cc4e5c",
+    "dark turquoise" => "#00ced1",
+    "dark violet" => "#9400d3",
+    "dartmouth green" => "#00693e",
+    "davy gray" => "#555555",
+
     "fuchsia" => "#ff00ff",
 
     "gray" => "#808080",
